CREATE SCHEMA "viewalyzer";

ALTER SCHEMA "viewalyzer" OWNER TO '&&viewalyzerUser&&';

CREATE TABLE viewalyzer.t_connection (
    connection_id integer NOT NULL,
    connection_ip character varying(255) NOT NULL,
    connection_port integer DEFAULT 5432 NOT NULL,
    connection_user character varying(100) NOT NULL,
    connection_password character varying(100) NOT NULL,
    connection_comment character varying(1000),
    connection_alias character varying(100) NOT NULL,
    connection_database_name character varying(100) NOT NULL,
    CONSTRAINT connection_chk1 CHECK (((connection_port >= 0) AND (connection_port <= 65535)))
);
ALTER TABLE viewalyzer.t_connection OWNER TO '&&viewalyzerUser&&';
CREATE SEQUENCE viewalyzer.s_connection_id
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;
ALTER TABLE viewalyzer.s_connection_id OWNER TO '&&viewalyzerUser&&';

CREATE SEQUENCE viewalyzer.s_database_id
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;

ALTER TABLE viewalyzer.s_database_id OWNER TO '&&viewalyzerUser&&';

CREATE SEQUENCE viewalyzer.s_owner_id
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;

ALTER TABLE viewalyzer.s_owner_id OWNER TO '&&viewalyzerUser&&';

CREATE SEQUENCE viewalyzer.s_schema_id
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;

ALTER TABLE viewalyzer.s_schema_id OWNER TO '&&viewalyzerUser&&';

CREATE SEQUENCE viewalyzer.s_view_id
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;

ALTER TABLE viewalyzer.s_view_id OWNER TO '&&viewalyzerUser&&';

CREATE TABLE viewalyzer.t_condat (
    condat_connection_id integer NOT NULL,
    condat_database_id integer NOT NULL,
   	condat_default_connection SMALLINT NOT NULL,
   	condat_active_connection SMALLINT NOT NULL,
    CONSTRAINT condat_cc1 CHECK (((condat_default_connection >= 0) AND (condat_default_connection <= 1)))
);

ALTER TABLE viewalyzer.t_condat OWNER TO '&&viewalyzerUser&&';

CREATE TABLE viewalyzer.t_database (
    database_id integer DEFAULT nextval('viewalyzer.s_database_id') NOT NULL,
    database_name character varying(100) NOT NULL,
    database_comment character varying(1000)
);

ALTER TABLE viewalyzer.t_database OWNER TO '&&viewalyzerUser&&';

CREATE TABLE viewalyzer.t_datown (
    datown_database_id integer NOT NULL,
    datown_owner_id integer NOT NULL
);

ALTER TABLE viewalyzer.t_datown OWNER TO '&&viewalyzerUser&&';

CREATE TABLE viewalyzer.t_message (
    message_id integer NOT NULL,
    message_msgtype_code character varying(3) NOT NULL,
    message_code character varying(32) NOT NULL,
    message_text character varying(2000) NOT NULL
);

ALTER TABLE viewalyzer.t_message OWNER TO '&&viewalyzerUser&&';

CREATE SEQUENCE viewalyzer.s_message_id
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;

ALTER TABLE viewalyzer.s_message_id OWNER TO '&&viewalyzerUser&&';

CREATE TABLE viewalyzer.t_msgtype (
    msgtype_code character varying(3) NOT NULL,
    msgtype_text character varying(200) NOT NULL
);

ALTER TABLE viewalyzer.t_msgtype OWNER TO '&&viewalyzerUser&&';

CREATE TABLE viewalyzer.t_owner (
    owner_id integer DEFAULT nextval('viewalyzer.s_owner_id') NOT NULL,
    owner_name character varying(100) NOT NULL,
    owner_comment character varying(1000)
);

ALTER TABLE viewalyzer.t_owner OWNER TO '&&viewalyzerUser&&';

CREATE TABLE viewalyzer.t_schema (
    schema_id integer DEFAULT nextval('viewalyzer.s_schema_id') NOT NULL,
    schema_name character varying(100) NOT NULL,
    schema_database_id integer NOT NULL,
    schema_comment character varying(1000)
);

ALTER TABLE viewalyzer.t_schema OWNER TO '&&viewalyzerUser&&';

CREATE TABLE viewalyzer.t_view (
    view_id integer DEFAULT nextval('viewalyzer.s_view_id') NOT NULL,
    view_name character varying(100) NOT NULL,
    view_comment character varying(1000),
    view_schema_id integer NOT NULL,
    view_owner_id integer DEFAULT 1 NOT NULL,
    view_ddl text NOT NULL
);

ALTER TABLE viewalyzer.t_view OWNER TO '&&viewalyzerUser&&';

CREATE TABLE "viewalyzer"."t_error_log" (
  "error_log_connection_alias" VARCHAR(100) NOT NULL, 
  "error_log_schema_name" VARCHAR(100) NOT NULL, 
  "error_log_view_name" VARCHAR(100) NOT NULL, 
  "error_log_view_ddl" TEXT NOT NULL,
  "error_log_message" VARCHAR(2000), 
  "error_log_timestamp" TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, 
  "error_log_comment" VARCHAR(1000)
) WITH OIDS;

ALTER TABLE "viewalyzer"."t_error_log" OWNER TO '&&viewalyzerUser&&';  
  
CREATE VIEW viewalyzer.v_database_owners AS
    SELECT b.owner_id AS database_owner_id, b.owner_name AS database_owner_name, a.database_id FROM viewalyzer.t_database a, viewalyzer.t_owner b, viewalyzer.t_datown c WHERE ((a.database_id = c.datown_database_id) AND (b.owner_id = c.datown_owner_id)) ORDER BY a.database_id;

ALTER TABLE viewalyzer.v_database_owners OWNER TO '&&viewalyzerUser&&';

CREATE VIEW viewalyzer.v_viewalyzer AS
    SELECT a.database_name AS viewalyzer_database_name, a.database_id AS viewalyzer_database_id, a.database_comment AS viewalyzer_database_comment, b.schema_id AS viewalyzer_schema_id, b.schema_name AS viewalyzer_schema_name, b.schema_comment AS viewalyzer_schema_comment, c.view_id AS viewalyzer_view_id, c.view_name AS viewalyzer_view_name, c.view_comment AS viewalyzer_view_comment, c.view_ddl AS viewalyzer_view_ddl, d.owner_id AS viewalyzer_owner_id, d.owner_name AS viewalyzer_owner_name, d.owner_comment AS viewalyzer_owner_comment FROM (viewalyzer.t_database a LEFT JOIN (viewalyzer.t_schema b LEFT JOIN (viewalyzer.t_view c JOIN viewalyzer.t_owner d ON ((d.owner_id = c.view_owner_id))) ON ((b.schema_id = c.view_schema_id))) ON ((a.database_id = b.schema_database_id))) ORDER BY a.database_name, b.schema_name, c.view_name;

ALTER TABLE viewalyzer.v_viewalyzer OWNER TO '&&viewalyzerUser&&';

ALTER TABLE viewalyzer.t_connection ALTER COLUMN connection_id SET DEFAULT nextval('viewalyzer.s_connection_id');

ALTER TABLE viewalyzer.t_message ALTER COLUMN message_id SET DEFAULT nextval('viewalyzer.s_message_id');

ALTER TABLE ONLY viewalyzer.t_message
    ADD CONSTRAINT message_uk1 UNIQUE (message_code);

ALTER TABLE ONLY viewalyzer.t_owner
    ADD CONSTRAINT owner_uk1 UNIQUE (owner_name);

ALTER TABLE ONLY viewalyzer.t_connection
    ADD CONSTRAINT connection_pk PRIMARY KEY (connection_id);

ALTER TABLE ONLY viewalyzer.t_database
    ADD CONSTRAINT database_pk PRIMARY KEY (database_id);

ALTER TABLE ONLY viewalyzer.t_msgtype
    ADD CONSTRAINT msgtype_pk PRIMARY KEY (msgtype_code);

ALTER TABLE ONLY viewalyzer.t_owner
    ADD CONSTRAINT owner_pk PRIMARY KEY (owner_id);

ALTER TABLE ONLY viewalyzer.t_schema
    ADD CONSTRAINT schema_pk PRIMARY KEY (schema_id);

ALTER TABLE ONLY viewalyzer.t_view
    ADD CONSTRAINT view_pk PRIMARY KEY (view_id);

CREATE UNIQUE INDEX condat_uk1 ON viewalyzer.t_condat USING btree (condat_connection_id, condat_database_id);

CREATE UNIQUE INDEX connection_uk1 ON viewalyzer.t_connection USING btree (connection_alias, connection_database_name, connection_ip, connection_port);

CREATE UNIQUE INDEX connection_uk2 ON viewalyzer.t_connection USING btree (connection_alias);

CREATE UNIQUE INDEX datown_uk1 ON viewalyzer.t_datown USING btree (datown_database_id, datown_owner_id);

CREATE UNIQUE INDEX schema_uk1 ON viewalyzer.t_schema USING btree (schema_name, schema_database_id);

CREATE UNIQUE INDEX "view_uk1" ON "viewalyzer"."t_view" USING btree ("view_name", "view_schema_id");

CREATE UNIQUE INDEX "error_log_uk1" ON "viewalyzer"."t_error_log" USING btree ("error_log_connection_alias", "error_log_schema_name", "error_log_view_name", "error_log_message");

ALTER TABLE ONLY viewalyzer.t_condat
    ADD CONSTRAINT condat_fk1 FOREIGN KEY (condat_connection_id) REFERENCES viewalyzer.t_connection(connection_id) ON UPDATE CASCADE ON DELETE CASCADE;

ALTER TABLE ONLY viewalyzer.t_condat
    ADD CONSTRAINT condat_fk2 FOREIGN KEY (condat_database_id) REFERENCES viewalyzer.t_database(database_id) ON UPDATE CASCADE ON DELETE CASCADE;

ALTER TABLE ONLY viewalyzer.t_datown
    ADD CONSTRAINT datown_fk1 FOREIGN KEY (datown_database_id) REFERENCES viewalyzer.t_database(database_id) ON UPDATE CASCADE ON DELETE RESTRICT;

ALTER TABLE ONLY viewalyzer.t_datown
    ADD CONSTRAINT datown_fk2 FOREIGN KEY (datown_owner_id) REFERENCES viewalyzer.t_owner(owner_id) ON UPDATE CASCADE ON DELETE RESTRICT;

ALTER TABLE ONLY viewalyzer.t_message
    ADD CONSTRAINT message_fk1 FOREIGN KEY (message_msgtype_code) REFERENCES viewalyzer.t_msgtype(msgtype_code) ON UPDATE CASCADE ON DELETE RESTRICT;

ALTER TABLE ONLY viewalyzer.t_schema
    ADD CONSTRAINT t_schema_fk FOREIGN KEY (schema_database_id) REFERENCES viewalyzer.t_database(database_id) ON UPDATE CASCADE ON DELETE CASCADE;

ALTER TABLE ONLY viewalyzer.t_view
    ADD CONSTRAINT t_view_fk FOREIGN KEY (view_schema_id) REFERENCES viewalyzer.t_schema(schema_id) ON UPDATE RESTRICT ON DELETE RESTRICT;

ALTER TABLE ONLY viewalyzer.t_view
    ADD CONSTRAINT t_view_fk1 FOREIGN KEY (view_owner_id) REFERENCES viewalyzer.t_owner(owner_id) ON UPDATE CASCADE ON DELETE SET DEFAULT;

INSERT INTO "viewalyzer"."t_msgtype" ("msgtype_code", "msgtype_text")
VALUES ('E', 'Error Message');

INSERT INTO "viewalyzer"."t_msgtype" ("msgtype_code", "msgtype_text")
VALUES ('I', 'Information Message');

INSERT INTO "viewalyzer"."t_msgtype" ("msgtype_code", "msgtype_text")
VALUES ('W', 'Warning Message');	
	

INSERT INTO "viewalyzer"."t_message" ("message_id", "message_msgtype_code", "message_code", "message_text")
VALUES (1, 'E', 'connection_uk1', 'A connection with same data is already existing');

INSERT INTO "viewalyzer"."t_message" ("message_id", "message_msgtype_code", "message_code", "message_text")
VALUES (2, 'E', 'connection_pk', 'A dataset with this key is already existing');

INSERT INTO "viewalyzer"."t_message" ("message_id", "message_msgtype_code", "message_code", "message_text")
VALUES (3, 'E', 'condat_uk1', 'The id of the connection and database is already in use');

INSERT INTO "viewalyzer"."t_message" ("message_id", "message_msgtype_code", "message_code", "message_text")
VALUES (4, 'E', 'connection_uk2', 'The alias name is already in use');

INSERT INTO "viewalyzer"."t_message" ("message_id", "message_msgtype_code", "message_code", "message_text")
VALUES (5, 'E', 'database_pk', 'A dataset with this key is already existing');

INSERT INTO "viewalyzer"."t_message" ("message_id", "message_msgtype_code", "message_code", "message_text")
VALUES (6, 'E', 'datown_uk1', 'An user in this database is already existing');

INSERT INTO "viewalyzer"."t_message" ("message_id", "message_msgtype_code", "message_code", "message_text")
VALUES (7, 'E', 'message_uk1', 'This code is already existing');

INSERT INTO "viewalyzer"."t_message" ("message_id", "message_msgtype_code", "message_code", "message_text")
VALUES (8, 'E', 'msgtype_pk', 'A dataset with this key is already existing');

INSERT INTO "viewalyzer"."t_message" ("message_id", "message_msgtype_code", "message_code", "message_text")
VALUES (9, 'E', 'owner_pk', 'A dataset with this key is already existing');

INSERT INTO "viewalyzer"."t_message" ("message_id", "message_msgtype_code", "message_code", "message_text")
VALUES (10, 'E', 'owner_uk1', 'This name is already in use. Please choose another one');

INSERT INTO "viewalyzer"."t_message" ("message_id", "message_msgtype_code", "message_code", "message_text")
VALUES (11, 'E', 'schema_pk', 'A dataset with this key is already existing');

INSERT INTO "viewalyzer"."t_message" ("message_id", "message_msgtype_code", "message_code", "message_text")
VALUES (12, 'E', 'schema_uk1', 'This schema is already existing');

INSERT INTO "viewalyzer"."t_message" ("message_id", "message_msgtype_code", "message_code", "message_text")
VALUES (13, 'E', 'view_pk', 'A dataset with this key is already existing');

INSERT INTO "viewalyzer"."t_message" ("message_id", "message_msgtype_code", "message_code", "message_text")
VALUES (14, 'E', 's_connection_id', 'Error while trying to access to sequence');

INSERT INTO "viewalyzer"."t_message" ("message_id", "message_msgtype_code", "message_code", "message_text")
VALUES (15, 'E', 's_database_id', 'Error while trying to access to sequence');

INSERT INTO "viewalyzer"."t_message" ("message_id", "message_msgtype_code", "message_code", "message_text")
VALUES (16, 'E', 's_message_id', 'Error while trying to access to sequence');

INSERT INTO "viewalyzer"."t_message" ("message_id", "message_msgtype_code", "message_code", "message_text")
VALUES (17, 'E', 's_owner_id', 'Error while trying to access to sequence');

INSERT INTO "viewalyzer"."t_message" ("message_id", "message_msgtype_code", "message_code", "message_text")
VALUES (18, 'E', 's_schema_id', 'Error while trying to access to sequence');

INSERT INTO "viewalyzer"."t_message" ("message_id", "message_msgtype_code", "message_code", "message_text")
VALUES (19, 'E', 's_view_id', 'Error while trying to access to sequence');

INSERT INTO "viewalyzer"."t_message" ("message_id", "message_msgtype_code", "message_code", "message_text")
VALUES (20, 'E', 'view_uk1', 'The view \"&&VIEWNAME&&\" is already in use');

INSERT INTO "viewalyzer"."t_message" ("message_id", "message_msgtype_code", "message_code", "message_text")
VALUES (21, 'E', 'condat_cc1', 'The given value for default connection is not valid');

INSERT INTO "viewalyzer"."t_message" ("message_id", "message_msgtype_code", "message_code", "message_text")
VALUES (22, 'E', 'log_error_uk1', 'The connection alias with this schema, this view and this error message already exist');

INSERT INTO "viewalyzer"."t_message" ("message_id", "message_msgtype_code", "message_code", "message_text")
VALUES (22, 'E', 'error_log_uk1', 'The connection alias with this schema, this view and this error message already exist');
